"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _clientEventbridge = require("@aws-sdk/client-eventbridge");
var _bluebird = _interopRequireDefault(require("bluebird"));
var _nodeHttpHandler = require("@smithy/node-http-handler");
var _utilRetry = require("@smithy/util-retry");
var _retry = require("../utils/retry");
var _log = require("../utils/log");
/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */

class Connector {
  constructor({
    debug,
    pipelineId,
    timeout = Number(process.env.BUS_TIMEOUT) || Number(process.env.TIMEOUT) || 1000,
    retryConfig = _retry.defaultRetryConfig
  }) {
    this.debug = msg => debug('%j', msg);
    this.bus = Connector.getClient(pipelineId, debug, timeout);
    this.retryConfig = retryConfig;
  }
  static clients = {};
  static getClient(pipelineId, debug, timeout) {
    if (!this.clients[pipelineId]) {
      this.clients[pipelineId] = new _clientEventbridge.EventBridgeClient({
        requestHandler: new _nodeHttpHandler.NodeHttpHandler({
          requestTimeout: timeout,
          connectionTimeout: timeout
        }),
        retryStrategy: new _utilRetry.ConfiguredRetryStrategy(11, _retry.defaultBackoffDelay),
        logger: (0, _log.defaultDebugLogger)(debug)
      });
    }
    return this.clients[pipelineId];
  }
  putEvents(params) {
    return this._putEvents(params, []);
  }
  _putEvents(params, attempts) {
    (0, _retry.assertMaxRetries)(attempts, this.retryConfig.maxRetries);
    return (0, _retry.wait)((0, _retry.getDelay)(this.retryConfig.retryWait, attempts.length)).then(() => _bluebird.default.resolve(this.bus.send(new _clientEventbridge.PutEventsCommand(params))).tap(this.debug).tapCatch(this.debug).then(resp => {
      if (resp.FailedEntryCount > 0) {
        return this._putEvents(unprocessed(params, resp), [...attempts, resp]);
      } else {
        return accumlate(attempts, resp);
      }
    }));
  }
}
var _default = exports.default = Connector;
const unprocessed = (params, resp) => ({
  ...params,
  Entries: params.Entries.filter((e, i) => resp.Entries[i].ErrorCode)
});
const accumlate = (attempts, resp) => attempts.reduceRight((a, c) => ({
  ...a,
  Entries: [...c.Entries.filter(e => !e.ErrorCode), ...a.Entries.filter(e => !e.ErrorCode)],
  attempts: [...attempts, resp]
}), resp);