"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _clientSecretsManager = require("@aws-sdk/client-secrets-manager");
var _nodeHttpHandler = require("@smithy/node-http-handler");
var _bluebird = _interopRequireDefault(require("bluebird"));
var _log = require("../utils/log");
/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */

/**
 * All secrets are combined to reduce the number of calls
 * Secrets are transferred from a ci/cd pipeline's secured variables
 * to SecretsManager using the serverless-secrets-mgr-plugin
 */
class Connector {
  constructor({
    debug,
    pipelineId,
    secretId,
    timeout = Number(process.env.SECRETSMGR_TIMEOUT) || Number(process.env.TIMEOUT) || 1000
  }) {
    this.debug = /* istanbul ignore next */msg => debug('%j', msg);
    this.secretId = secretId;
    this.sm = Connector.getClient(pipelineId, debug, timeout);
  }
  static clients = {};
  static getClient(pipelineId, debug, timeout) {
    if (!this.clients[pipelineId]) {
      this.clients[pipelineId] = new _clientSecretsManager.SecretsManagerClient({
        requestHandler: new _nodeHttpHandler.NodeHttpHandler({
          requestTimeout: timeout,
          connectionTimeout: timeout
        }),
        logger: (0, _log.defaultDebugLogger)(debug)
      });
    }
    return this.clients[pipelineId];
  }
  async get() {
    if (!this.secrets) {
      const params = {
        SecretId: this.secretId
      };
      this.secrets = await _bluebird.default.resolve(this.sm.send(new _clientSecretsManager.GetSecretValueCommand(params))).tapCatch(this.debug).then(data => Buffer.from(data.SecretString, 'base64').toString()).then(data => JSON.parse(data));
    }
    return this.secrets;
  }
}
var _default = exports.default = Connector;